# Flask-Themes2

[docs]: https://flask-themes2.readthedocs.io/en/latest/
[GitHub]: https://github.com/sysr-q/flask-themes2

Flask-Themes2 is a fork of Spirits, which is in turn a fork of Flask-Themes.

- [Flask-Themes2](https://github.com/sysr-q/flask-themes2) maintained by Chris Carter
- [Spirits](https://github.com/drewlustro/spirits) maintained by Drew Lustro
- [Flask-Themes](https://bitbucket.org/leafstorm/flask-themes) by Matthew "LeafStorm" Frazier
- Many more contributors to this fork and all others! It wouldn't be this good without you.

This provides infrastructure for themes in Flask >= 2.0.


## Installation

To install normally:
```sh
$ pip install flask-themes2
```

To install the development (latest) version:
```sh
$ pip install -e git://github.com/sysr-q/flask-themes2.git#egg=flask_themes2-dev
```

## Documentation

The documentation is on the Flask-Themes2 [docs].

## Development

If you're interested in helping, the source is available on [GitHub], feel free to contribute.
